@@ -52,7 +52,7 @@ excluded_files = [
 
 ## TODO: Can the script deduce this list?
 openjdk_copyrights = [
-  "Copyright (c) 1996-2023 Oracle and/or its affiliates.",
+  "Copyright (c) 1996-2025 Oracle and/or its affiliates.",
   "Copyright (c) 1996-2003 Sun Microsystems, Inc.",
   "Copyright (c) 2009-2012 Red Hat, Inc.",
   "Copyright (c) 2012-2022 SAP SE.",
@@ -133,7 +133,7 @@ def generate_comment_str():
 def generate_header_stanza():
   format = "https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/"
   excluded = generate_excluded_files_str()
-  source = "https://github.com/openjdk/jdk24u"
+  source = "https://github.com/openjdk/jdk"
   comment = generate_comment_str()
   print_header_stanza(format, excluded, source, comment)
 
@@ -285,7 +285,7 @@ def main():
   version = detect_version()
 
   sys.stdout = open('./debian/copyright', 'w')
-  supported_versions = ["11", "17", "21", "22", "23", "24"]
+  supported_versions = ["11", "17", "21", "22", "23", "24", "25"]
 
   if version in supported_versions:
     generate_copyright()
